@@ -37,16 +37,17 @@
 #define HCX_CLIENT_PORT				37
 #define HCX_CHECK_DRIVER			38
 #define HCX_CHECK_INJECTION			39
-#define HCX_ERROR_MAX				40
-#define HCX_STATUS				41
-#define HCX_BEACONPARAMS			42
-#define HCX_WPAENT				43
-#define HCX_EAPREQ				44
-#define HCX_EAPREQ_FOLLOWNAK	45
-#define HCX_EAPTUN				46
-#define HCX_EAP_SERVER_CERT			47
-#define HCX_EAP_SERVER_KEY			48
-#define HCX_EAPOL_EAP_TIMEOUT			49
+#define HCX_FORCE_INTERFACE			40
+#define HCX_ERROR_MAX				41
+#define HCX_STATUS				42
+#define HCX_BEACONPARAMS			43
+#define HCX_WPAENT				44
+#define HCX_EAPREQ				45
+#define HCX_EAPREQ_FOLLOWNAK			46
+#define HCX_EAPTUN				47
+#define HCX_EAP_SERVER_CERT			48
+#define HCX_EAP_SERVER_KEY			49
+#define HCX_EAPOL_EAP_TIMEOUT			50
 #define HCX_INTERFACE_NAME			'i'
 #define HCX_PCAPNG_NAME				'o'
 #define HCX_PACPNG_FRAMES			'f'
@@ -71,6 +72,7 @@
 #define EAPLIST_MAX		1024
 #define EAPREQLIST_MAX		20
 
+#define FSCANLIST_MAX		1000
 #define SCANLIST_MAX		256
 #define FILTERLIST_MAX		256
 #define	FILTERLIST_LINE_LEN	256
@@ -372,6 +374,7 @@ typedef struct
  unsigned int		hit;
  char			rssi;
  uint8_t		channel;
+ unsigned int		frequency;
  uint8_t		essidlen;
  uint8_t		essid[ESSID_LEN_MAX];
 }scanlist_t;
@@ -439,3 +442,10 @@ uint8_t			mode;
 }eapreqlist_t;
 #define EAPREQLIST_SIZE (sizeof(eapreqlist_t))
 /*===========================================================================*/
+typedef struct
+{
+int	frequency;
+int	channel;
+}fscanlist_t;
+#define	FSCANLIST_SIZE (sizeof(fscanlist_t))
+/*===========================================================================*/
