@@ -1,4 +1,4 @@
-#define GPIO_DELAY	100000
+#define GPIO_LED_DELAY	100000000
 
 #define GPIO_PERI_BASE_OLD	0x20000000
 #define GPIO_PERI_BASE_NEW	0x3F000000
